/**
 * This file is responsible for asking and setting up babeljs
 */
const inquirer = require('inquirer')
const fs = require('fs-extra')
const _ = require('lodash')

const confirmQuestion = {
  type: 'confirm',
  name: 'confirm',
  message: 'Set up Babel ?',
  default: false
}

const presetsQuestion = {
  type: 'checkbox',
  name: 'presets',
  message: 'Choose one or more of the following Babel presets: ',
  choices: [
    'babel-preset-env',
    'babel-preset-es2015',
    'babel-preset-react',
    'babel-preset-es2016',
    'babel-preset-es2017'
  ]
}

module.exports = () => new Promise((resolve, reject) => {
  inquirer.prompt(confirmQuestion).then(({confirm}) => {
    if (_.isBoolean(confirm)) {
      if (confirm === true) {
        inquirer.prompt(presetsQuestion).then(({presets}) => {
          const answerInString = _.toString(presets)
          const dependenciesList = _.replace(answerInString, /[,]/g, ' ')
          const fileList = _.split(_.replace(dependenciesList, /babel-preset-/g, ''), /\s/g)
          const fileTemplate = {
            presets: fileList
          }
          fs.outputFileSync(`${process.cwd()}/.babelrc`, JSON.stringify(fileTemplate, null, '\t'))
          resolve('babel-core ' + dependenciesList)
        })
      } else {
        resolve()
      }
    } else {
      reject(new Error("Can't quite get the answer"))
    }
  })
})
