const inquirer = require('inquirer')
const _ = require('lodash')

const confirmQuestion = {
  type: 'confirm',
  name: 'confirm',
  message: 'Install some dependencies ?',
  default: false
}

const cssDependenciesQuestion = {
  type: 'checkbox',
  name: 'css',
  message: 'Choose any of these CSS dependencies: ',
  choices: [
    'bootstrap',
    'font-awesome',
    'normalize-css',
    'bulma',
    'foundation-sites'
  ]
}

const frontEndDependencies = {
  type: 'checkbox',
  name: 'frontend',
  message: 'Choose any of these front end dependencies: ',
  choices: [
    'react',
    'react-dom',
    'vue',
    'redux',
    'react-redux',
    'vuex',
    'moon',
    'preact',
    'jquery',
    'moment',
    'lodash',
    'underscore'
  ]
}

const backEndDependencies = {
  type: 'checkbox',
  name: 'backend',
  message: 'Choose any of these back end dependencies: ',
  choices: [
    'express',
    'hapi',
    'socket.io',
    'sails',
    'koa',
    'passport'
  ]
}

const cliDependencies = {
  type: 'checkbox',
  name: 'cli',
  message: 'Choose any of these CLI dependencies: ',
  choices: [
    'inquirer',
    'yargs',
    'commander',
    'fs-extra',
    'mkdirp',
    'chalk',
    'colors',
    'meow',
    'boxen',
    'cli-cursor',
    'ora'
  ]
}

const questions = [
  cssDependenciesQuestion,
  frontEndDependencies,
  backEndDependencies,
  cliDependencies
]

module.exports = () => new Promise((resolve, reject) => {
  inquirer.prompt(confirmQuestion).then(({confirm}) => {
    if (_.isBoolean(confirm)) {
      if (confirm === true) {
        inquirer.prompt(questions).then(({css, frontend, backend, cli}) => {
          const cssDependencies = _.replace(_.toString(css), /[,]/g, ' ')
          const frontEndDependencies = _.replace(_.toString(frontend), /[,]/g, ' ')
          const backEndDependencies = _.replace(_.toString(backend), /[,]/g, ' ')
          const cliDependencies = _.replace(_.toString(cli), /[,]/g, ' ')
          resolve(`${cssDependencies} ${frontEndDependencies} ${backEndDependencies} ${cliDependencies}`)
        })
      } else {
        resolve()
      }
    } else {
      reject(new Error("Couldn't quite get the answer"))
    }
  })
})
