/**
 * This file is responsible to handle setting up eslint for the user
 */

const inquirer = require('inquirer')
const fs = require('fs-extra')
const _ = require('lodash')

const confirmQuestion = { type: 'confirm', name: 'eslint', message: 'Set up Eslint ?', default: false }
const styleGuidesQuestion = { type: 'list', name: 'guide', message: 'Choose any of the following style guide: ', choices: ['Google', 'Standard', 'Airbnb'] }
const airbnbReactQuestion = { type: 'confirm', name: 'react', message: 'Are you going to use React ?', default: false }

const writeEslintConfigFile = (guide) => {
  const template = `{\n\t"extends": "${guide.toLowerCase()}"\n}`
  fs.outputFileSync(`${process.cwd()}/.eslintrc.json`, template)
}

module.exports = () => new Promise((resolve, reject) => {
  inquirer.prompt(confirmQuestion).then(({eslint}) => {
    if (_.isBoolean(eslint)) {
      if (eslint === true) {
        inquirer.prompt(styleGuidesQuestion).then(({guide}) => {
          if (guide === 'Google' || guide === 'Standard') {
            writeEslintConfigFile(guide)
          } else {
            inquirer.prompt(airbnbReactQuestion).then(({react}) => {
              if (react === true) {
                writeEslintConfigFile('Airbnb')
                resolve('eslint eslint-config-airbnb eslint-plugin-import eslint-plugin-jsx-a11y eslint-plugin-react')
              } else {
                writeEslintConfigFile('Airbnb-base')
                resolve('eslint eslint-config-airbnb-base eslint-plugin-import')
              }
            })
          }
          if (guide === 'Google') {
            resolve('eslint-config-google eslint')
          } else if (guide === 'Standard') {
            resolve('eslint-plugin-standard eslint-config-standard eslint-plugin-import eslint-plugin-promise eslint-plugin-node eslint')
          }
        })
      } else {
        resolve()
      }
    } else {
      reject(new Error('Answer cant be identified'))
    }
  })
})
