/**
 * This file is responsible to ask and write a .gitignore file
 */

const inquirer = require('inquirer')
const fs = require('fs-extra')
const _ = require('lodash')

const question = {
  type: 'confirm',
  name: 'gitignore',
  message: 'Create a .gitignore file ?',
  default: false
}

const template = `# https://gist.github.com/octocat/9257657 #
# Compiled source #
###################
*.com
*.class
*.dll
*.exe
*.o
*.so

# Packages #
############
# it's better to unpack these files and commit the raw source
# git has its own built in compression methods
*.7z
*.dmg
*.gz
*.iso
*.jar
*.rar
*.tar
*.zip

# Logs and databases #
######################
*.log
*.sql
*.sqlite

# OS generated files #
######################
.DS_Store
.DS_Store?
._*
.Spotlight-V100
.Trashes
ehthumbs.db
Thumbs.db
`

module.exports = () => new Promise((resolve, reject) => {
  inquirer.prompt(question).then(({gitignore}) => {
    if (gitignore === true) {
      fs.outputFileSync(`${process.cwd()}/.gitignore`, template)
      resolve()
    } else if (_.isBoolean(gitignore) !== true) {
      reject(new Error("Can't identify the answer"))
    } else {
      resolve()
    }
  })
})
