const inquirer = require('inquirer')
const fs = require('fs-extra')
const _ = require('lodash')

const confirmQuestion = {
  type: 'confirm',
  name: 'confirm',
  message: 'Set up Gulp ?',
  default: false
}

const pluginsQuestion = {
  type: 'checkbox',
  name: 'plugins',
  message: 'Choose any of the following plugins: ',
  choices: [
    'gulp-babel',
    'gulp-uglify',
    'gulp-browserify',
    'gulp-rollup',
    'gulp-plumber',
    'gulp-postcss',
    'gulp-rename',
    'gulp-imagemin',
    'gulp-pug',
    'gulp-sass',
    'gulp-stylus',
    'gulp-less',
    'gulp-csso',
    'gulp-util',
    'gulp-sourcemaps',
    'gulp-concat',
    'gulp-eslint',
    'gulp-typescript',
    'gulp-coffee',
    'gulp-load-plugins',
    'gulp-size',
    'gulp-watch'
  ]
}

const fileQuestion = {
  type: 'confirm',
  name: 'file',
  message: 'Create gulpfile.js ?',
  default: false
}

const questions = [
  fileQuestion,
  pluginsQuestion
]

const template = `const gulp = require('gulp')

gulp.task('default', () => {
  // write your default task here
})`

module.exports = () => new Promise((resolve, reject) => {
  inquirer.prompt(confirmQuestion).then(({confirm}) => {
    if (_.isBoolean(confirm)) {
      if (confirm === true) {
        inquirer.prompt(questions).then(({file, plugins}) => {
          if (file === true) {
            fs.outputFileSync(`${process.cwd()}/gulpfile.js`, template)
          }
          resolve(`gulp ${_.replace(_.toString(plugins), /[,]/g, ' ')}`)
        })
      } else {
        resolve()
      }
    } else {
      reject(new Error("Can't quite get the answer"))
    }
  })
})
