const program = require('commander')
const shell = require('shelljs')
const _ = require('lodash')
const pkg = require('../package.json')
const colors = require('colors')
const Ora = require('ora')
const cliSpinners = require('cli-spinners')
const dependenciesList = require('./dependenciesList')
const update = require('./update')

program
  .version(pkg.version)
  .option('-y, --yarn', 'Install dependencies using yarn')
  .option('-p, --pnpm', 'Install dependencies using pnpm')
  .parse(process.argv)

const installDependencies = (dependenciesList, development = false) => new Promise((resolve) => {
  const dependencies = _.replace(dependenciesList, /^\s/, '')
  const yarn = program.yarn
  const pnpm = program.pnpm
  let command
  if (yarn === true) {
    if (development === false) {
      command = `yarn add ${dependencies}`
    } else {
      command = `yarn add --dev ${dependencies}`
    }
  } else if (pnpm === true) {
    if (development === false) {
      command = `pnpm install --save ${dependencies}`
    } else {
      command = `pnpm install --save-dev ${dependencies}`
    }
  } else {
    if (development === false) {
      command = `npm install --save ${dependencies}`
    } else {
      command = `npm install --save-dev ${dependencies}`
    }
  }
  let text
  if (development === false) {
    text = ' dependencies'
  } else {
    text = ' development dependencies'
  }
  const spinner = new Ora({
    text: 'Installing' + text,
    spinner: cliSpinners.line
  }).start()
  shell.exec(command, {silent: true}, (code) => {
    if (code === 1) {
      spinner.fail(`${colors.bgRed.black(' error ')} failed to install` + text)
      resolve()
    } else {
      spinner.succeed(`${colors.bgGreen.black(' success ')} successfully installed` + text)
      resolve()
    }
  })
})

module.exports = () => new Promise((resolve, reject) => {
  dependenciesList().then(({dependencies, devDependencies}) => {
    if (_.isUndefined(dependencies) || _.isUndefined(devDependencies)) {
      reject(new Error("Can't get the dependencies or the development dependencies list"))
    } else {
      if (_.isEmpty(_.replace(dependencies, /^\s/, '')) === false) {
        installDependencies(dependencies, false).then(() => {
          if (_.isEmpty(_.replace(devDependencies, /^\s/, '')) === false) {
            installDependencies(devDependencies, true).then(() => {
              update()
            })
          } else {
            update()
          }
        })
      } else {
        if (_.isEmpty(_.replace(devDependencies, /^\s/, '')) === false) {
          installDependencies(devDependencies, true).then(() => {
            update()
          })
        } else {
          update()
        }
      }
    }
  })
})
