/**
 * This file is responsible to write a LICENSE.md file for the user
 */

const inquirer = require('inquirer')
const fs = require('fs-extra')
const _ = require('lodash')

const mit = require('./licenses/mit')
const apache = require('./licenses/apache')
const agpl3 = require('./licenses/a-gpl3.0')
const bsd2 = require('./licenses/bsd-2')
const bsd3 = require('./licenses/bsd-3')
const eclipse = require('./licenses/eclipse-1.0')
const gpl2 = require('./licenses/gpl2.0')
const gpl3 = require('./licenses/gpl3.0')
const lgpl2 = require('./licenses/lgpl-2.0')
const lgpl3 = require('./licenses/lgpl-3.0')
const mozilla = require('./licenses/mozilla-2.0')
const unlicense = require('./licenses/unlicense')
const isc = require('./licenses/isc')

const question = {
  type: 'confirm',
  name: 'confirm',
  message: 'Create a LICENSE.md file ?',
  default: false
}

module.exports = (license, author = '') => new Promise((resolve, reject) => {
  if (_.isUndefined(license)) {
    reject(new Error('License is not defined'))
  } else {
    inquirer.prompt(question).then(({confirm}) => {
      if (_.isUndefined(confirm)) {
        reject(new Error("Couldn't quite get the answer"))
      } else {
        if (confirm === true) {
          let template
          switch (license) {
            case 'MIT':
              template = mit(author)
              break
            case 'ISC':
              template = isc(author)
              break
            case 'Apache-2.0':
              template = apache
              break
            case 'AGPL-3.0':
              template = agpl3
              break
            case 'BSD-2-Clause':
              template = bsd2(author)
              break
            case 'BSD-3-Clause':
              template = bsd3(author)
              break
            case 'EPL-1.0':
              template = eclipse
              break
            case 'GPL-2.0':
              template = gpl2(author)
              break
            case 'GPL-3.0':
              template = gpl3(author)
              break
            case 'LGPL-2.1':
              template = lgpl2(author)
              break
            case 'LGPL-3.0':
              template = lgpl3
              break
            case 'MPL-2.0':
              template = mozilla
              break
            case 'Unlicense':
              template = unlicense
              break
            default:
              template = ''
          }
          fs.outputFileSync(`${process.cwd()}/LICENSE`, template)
          resolve()
        } else {
          resolve()
        }
      }
    })
  }
})
