/**
 * This file is responsible for setting up mocha testing
 */
const inquirer = require('inquirer')
const _ = require('lodash')

const confirmQuestion = {
  type: 'confirm',
  name: 'confirm',
  message: 'Set up Mocha ?',
  default: false
}

const assertionQuestion = {
  type: 'list',
  name: 'assert',
  message: 'Choose any of the following assertion libraries: ',
  choices: [
    'chai',
    'expect.js',
    'should',
    'better-assert',
    'unexpected',
    'other'
  ]
}

const chaiPluginsQuestion = {
  type: 'checkbox',
  name: 'chaiPlugins',
  message: 'Choose any of the following chai plugins: ',
  choices: [
    'chai-as-promised',
    'chai-sinon',
    'chai-fs',
    'chai-json',
    'chai-jquery'
  ]
}

const unexpectedPluginsQuestion = {
  type: 'checkbox',
  name: 'unexpectedPlugins',
  message: 'Choose any of the following unexpected plugins: ',
  choices: [
    'unexpected-sinon',
    'unexpected-color',
    'unexpected-check',
    'unexpected-dom',
    'unexpected-react'
  ]
}

module.exports = () => new Promise((resolve, reject) => {
  inquirer.prompt(confirmQuestion).then(({confirm}) => {
    if (_.isBoolean(confirm)) {
      if (confirm === true) {
        inquirer.prompt(assertionQuestion).then(({assert}) => {
          if (assert === 'other') {
            resolve('mocha ')
          } else if (assert === 'chai') {
            inquirer.prompt(chaiPluginsQuestion).then(({chaiPlugins}) => {
              resolve('mocha chai ' + _.replace(_.toString(chaiPlugins), /[,]/g, ' '))
            })
          } else if (assert === 'unexpected') {
            inquirer.prompt(unexpectedPluginsQuestion).then(({unexpectedPlugins}) => {
              resolve('mocha unexpected ' + _.replace(_.toString(unexpectedPlugins), /[,]/g, ' '))
            })
          } else {
            resolve('mocha ' + assert)
          }
        })
      } else {
        resolve()
      }
    } else {
      reject(new Error("Can't quite get the answer"))
    }
  })
})
