const inquirer = require('inquirer')
const fs = require('fs-extra')
const _ = require('lodash')

const confirmQuestion = {
  type: 'confirm',
  name: 'confirm',
  message: 'Set up webpack ?',
  default: false
}

const webpackConfigQuestion = {
  type: 'confirm',
  name: 'config',
  message: 'Create a webpack.config.js ?',
  default: false
}

const webpackLoadersQuestion = {
  type: 'checkbox',
  name: 'loaders',
  message: 'Choose any of these loaders: ',
  choices: [
    'babel-loader',
    'css-loader',
    'style-loader',
    'postcss-loader',
    'sass-loader',
    'stylus-loader',
    'file-loader',
    'url-loader',
    'eslint-loader',
    'vue-loader',
    'ts-loader',
    'img-loader',
    'pug-loader',
    'html-loader'
  ]
}

const webpackPluginsQuestion = {
  type: 'checkbox',
  name: 'plugins',
  message: 'Choose any of these plugins: ',
  choices: [
    'html-webpack-plugin',
    'extract-text-webpack-plugin',
    'imagemin-webpack-plugin',
    'webpack-manifest-plugin',
    'uglifyjs-webpack-plugin',
    'clean-webpack-plugin'
  ]
}

const webpackToolsQuestion = {
  type: 'checkbox',
  name: 'tools',
  message: 'Choose any of these tools: ',
  choices: [
    'webpack-dev-middleware',
    'webpack-dev-server',
    'webpack-dashboard'
  ]
}

const questions = [
  webpackConfigQuestion,
  webpackLoadersQuestion,
  webpackPluginsQuestion,
  webpackToolsQuestion
]

const template = `const path = require('path')

module.exports = {
  entry: './path/to/entry.js',
  output: {
    path: path.resolve(__dirname, "dist"),
    filename: "fileName.js"
  }
}`

module.exports = () => new Promise((resolve, reject) => {
  inquirer.prompt(confirmQuestion).then(({confirm}) => {
    if (_.isBoolean(confirm)) {
      if (confirm === true) {
        inquirer.prompt(questions).then(({config, loaders, plugins, tools}) => {
          if (_.isBoolean(config)) {
            if (config === true) {
              fs.outputFileSync(`${process.cwd()}/webpack.config.js`, template)
            }
            let loadersList = _.replace(_.toString(loaders), /[,]/g, ' ')
            const pluginsList = _.replace(_.toString(plugins), /[,]/g, ' ')
            const toolsList = _.replace(_.toString(tools), /[,]/g, ' ')
            
            if (loadersList.includes('pug-loader')) {
              loadersList = `${loadersList} pug`
            }
            if (loadersList.includes('postcss-loader')) {
              loadersList = `${loadersList} postcss`
            }
            if (loadersList.includes('stylus-loader')) {
              loadersList = `${loadersList} stylus`
            }
            if (loadersList.includes('sass-loader')) {
              loadersList = `${loadersList} node-sass`
            }
            if (loadersList.includes('eslint-loader')) {
              loadersList = `${loadersList} eslint`
            }
            if (loadersList.includes('less-loader')) {
              loadersList = `${loadersList} less`
            }
            if (loadersList.includes('babel-loader')) {
              loadersList = `${loadersList} babel-core`
            }

            resolve(`webpack ${loadersList} ${pluginsList} ${toolsList} `)
          } else {
            reject(new Error("Can't quite figure out the answer"))
          }
        })
      } else {
        resolve()
      }
    } else {
      reject(new Error("Can't quite figure out the answer"))
    }
  })
})
